@@ -2,21 +2,39 @@ package ExtUtils::Command;
 
 use 5.00503;
 use strict;
-use Carp;
-use File::Copy;
-use File::Compare;
-use File::Basename;
-use File::Path qw(rmtree);
 require Exporter;
 use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
 @ISA       = qw(Exporter);
 @EXPORT    = qw(cp rm_f rm_rf mv cat eqtime mkpath touch test_f test_d chmod
                 dos2unix);
-$VERSION = '1.15';
+$VERSION = '1.19';
 
 my $Is_VMS   = $^O eq 'VMS';
+my $Is_VMS_mode = $Is_VMS;
+my $Is_VMS_noefs = $Is_VMS;
 my $Is_Win32 = $^O eq 'MSWin32';
 
+if( $Is_VMS ) {
+    my $vms_unix_rpt;
+    my $vms_efs;
+    my $vms_case;
+
+    if (eval { local $SIG{__DIE__}; require VMS::Feature; }) {
+        $vms_unix_rpt = VMS::Feature::current("filename_unix_report");
+        $vms_efs = VMS::Feature::current("efs_charset");
+        $vms_case = VMS::Feature::current("efs_case_preserve");
+    } else {
+        my $unix_rpt = $ENV{'DECC$FILENAME_UNIX_REPORT'} || '';
+        my $efs_charset = $ENV{'DECC$EFS_CHARSET'} || '';
+        my $efs_case = $ENV{'DECC$EFS_CASE_PRESERVE'} || '';
+        $vms_unix_rpt = $unix_rpt =~ /^[ET1]/i;
+        $vms_efs = $efs_charset =~ /^[ET1]/i;
+        $vms_case = $efs_case =~ /^[ET1]/i;
+    }
+    $Is_VMS_mode = 0 if $vms_unix_rpt;
+    $Is_VMS_noefs = 0 if ($vms_efs);
+}
+
 
 =head1 NAME
 
@@ -74,7 +92,7 @@ sub expand_wildcards
 
 Concatenates all files mentioned on command line to STDOUT.
 
-=cut 
+=cut
 
 sub cat ()
 {
@@ -88,7 +106,7 @@ sub cat ()
 
 Sets modified time of destination to that of source.
 
-=cut 
+=cut
 
 sub eqtime
 {
@@ -103,12 +121,13 @@ sub eqtime
 
 Removes files and directories - recursively (even if readonly)
 
-=cut 
+=cut
 
 sub rm_rf
 {
  expand_wildcards();
- rmtree([grep -e $_,@ARGV],0,0);
+ require File::Path;
+ File::Path::rmtree([grep -e $_,@ARGV],0,0);
 }
 
 =item rm_f
@@ -117,7 +136,7 @@ sub rm_rf
 
 Removes files (even if readonly)
 
-=cut 
+=cut
 
 sub rm_f {
     expand_wildcards();
@@ -131,7 +150,8 @@ sub rm_f {
 
         next if _unlink($file);
 
-        carp "Cannot delete $file: $!";
+        require Carp;
+        Carp::carp("Cannot delete $file: $!");
     }
 }
 
@@ -150,9 +170,9 @@ sub _unlink {
 
     touch file ...
 
-Makes files exist, with current timestamp 
+Makes files exist, with current timestamp
 
-=cut 
+=cut
 
 sub touch {
     my $t    = time;
@@ -174,18 +194,22 @@ destination is an existing directory.
 
 Returns true if all moves succeeded, false otherwise.
 
-=cut 
+=cut
 
 sub mv {
     expand_wildcards();
     my @src = @ARGV;
     my $dst = pop @src;
 
-    croak("Too many arguments") if (@src > 1 && ! -d $dst);
+    if (@src > 1 && ! -d $dst) {
+        require Carp;
+        Carp::croak("Too many arguments");
+    }
 
+    require File::Copy;
     my $nok = 0;
     foreach my $src (@src) {
-        $nok ||= !move($src,$dst);
+        $nok ||= !File::Copy::move($src,$dst);
     }
     return !$nok;
 }
@@ -207,11 +231,15 @@ sub cp {
     my @src = @ARGV;
     my $dst = pop @src;
 
-    croak("Too many arguments") if (@src > 1 && ! -d $dst);
+    if (@src > 1 && ! -d $dst) {
+        require Carp;
+        Carp::croak("Too many arguments");
+    }
 
+    require File::Copy;
     my $nok = 0;
     foreach my $src (@src) {
-        $nok ||= !copy($src,$dst);
+        $nok ||= !File::Copy::copy($src,$dst);
 
         # Win32 does not update the mod time of a copied file, just the
         # created time which make does not look at.
@@ -226,14 +254,15 @@ sub cp {
 
 Sets UNIX like permissions 'mode' on all the files.  e.g. 0666
 
-=cut 
+=cut
 
 sub chmod {
     local @ARGV = @ARGV;
     my $mode = shift(@ARGV);
     expand_wildcards();
 
-    if( $Is_VMS ) {
+    if( $Is_VMS_mode && $Is_VMS_noefs) {
+        require File::Spec;
         foreach my $idx (0..$#ARGV) {
             my $path = $ARGV[$idx];
             next unless -d $path;
@@ -257,11 +286,12 @@ sub chmod {
 
 Creates directories, including any parent directories.
 
-=cut 
+=cut
 
 sub mkpath
 {
  expand_wildcards();
+ require File::Path;
  File::Path::mkpath([@ARGV],0,0777);
 }
 
@@ -272,7 +302,7 @@ sub mkpath
 Tests if a file exists.  I<Exits> with 0 if it does, 1 if it does not (ie.
 shell's idea of true and false).
 
-=cut 
+=cut
 
 sub test_f
 {
@@ -314,9 +344,9 @@ sub dos2unix {
 	my $orig = $_;
 	my $temp = '.dos2unix_tmp';
 	open ORIG, $_ or do { warn "dos2unix can't open $_: $!"; return };
-	open TEMP, ">$temp" or 
+	open TEMP, ">$temp" or
 	    do { warn "dos2unix can't create .dos2unix_tmp: $!"; return };
-        while (my $line = <ORIG>) { 
+        while (my $line = <ORIG>) {
             $line =~ s/\015\012/\012/g;
             print TEMP $line;
         }
@@ -343,4 +373,3 @@ ExtUtils-MakeMaker package and, as a separate CPAN package, by
 Randy Kobes C<r.kobes@uwinnipeg.ca>.
 
 =cut
-
